@@ -88,8 +88,9 @@ public:
     void StatsAccountLQ(int64_t diffTime);
     void StatsAccountMQ(int64_t diffTime);
     void StatsAccountHQ(int64_t diffTime);
-    void CalcWaitTime(ThreadPriority p, ThreadPoolJob *job);
+    void CalcWaitTime(ThreadPriority p, const std::unique_ptr<ThreadPoolJob>& job);
     void bumpPriority();
+    void WorkerThread();
     int shutdown();
     
     /*! Mutex to protect job qs. */
@@ -112,13 +113,13 @@ public:
     /*! number of persistent threads */
     int persistentThreads;
     /*! low priority job Q */
-    std::deque<ThreadPoolJob*> lowJobQ;
+    std::deque<std::unique_ptr<ThreadPoolJob>> lowJobQ;
     /*! med priority job Q */
-    std::deque<ThreadPoolJob*> medJobQ;
+    std::deque<std::unique_ptr<ThreadPoolJob>> medJobQ;
     /*! high priority job Q */
-    std::deque<ThreadPoolJob*> highJobQ;
+    std::deque<std::unique_ptr<ThreadPoolJob>> highJobQ;
     /*! persistent job */
-    ThreadPoolJob *persistentJob;
+    std::unique_ptr<ThreadPoolJob> persistentJob;
     /*! thread pool attributes */
     ThreadPoolAttr attr;
     /*! statistics */
@@ -131,8 +132,8 @@ ThreadPool::ThreadPool()
 {
 }
 
-ThreadPool::~ThreadPool()
 #if 0
+ThreadPool::~ThreadPool()
 {
     // JFD: Doing a proper shutdown does not work at the moment. One
     // of the threads does not exit. I suspect it's the timer thread
@@ -147,8 +148,6 @@ ThreadPool::~ThreadPool()
     shutdown();
     delete m;
 }
-#else
-= default;
 #endif
 
 int ThreadPool::start(ThreadPoolAttr *attr)
@@ -187,7 +186,7 @@ void ThreadPool::Internal::StatsAccountHQ(int64_t diffTime)
  *
  * \internal
  */
-void ThreadPool::Internal::CalcWaitTime(ThreadPriority p, ThreadPoolJob *job)
+void ThreadPool::Internal::CalcWaitTime(ThreadPriority p, const std::unique_ptr<ThreadPoolJob>& job)
 {
     assert(job != nullptr);
 
@@ -304,42 +303,39 @@ exit_function:
  * \brief Determines whether any jobs need to be bumped to a higher priority Q
  * and bumps them.
  *
- * tp->mutex must be locked.
+ * mutex must be locked.
  *
  * \internal
- * 
+ *
  * \return
  */
 void ThreadPool::Internal::bumpPriority()
 {
     int done = 0;
-    ThreadPoolJob *tempJob = nullptr;
-
     auto now = steady_clock::now();
+
     while (!done) {
-        if (!this->medJobQ.empty()) {
-            tempJob = this->medJobQ.front();
+        if (!medJobQ.empty()) {
             auto diffTime = duration_cast<milliseconds>(
-                now - tempJob->requestTime).count();
-            if (diffTime >= this->attr.starvationTime) {
+                now - medJobQ.front()->requestTime).count();
+            if (diffTime >= attr.starvationTime) {
                 /* If job has waited longer than the starvation time
                  * bump priority (add to higher priority Q) */
                 StatsAccountMQ(diffTime);
-                this->medJobQ.pop_front();
-                this->highJobQ.push_back(tempJob);
+                highJobQ.push_back(std::move(medJobQ.front()));
+                medJobQ.pop_front();
                 continue;
             }
         }
-        if (!this->lowJobQ.empty()) {
-            tempJob = this->lowJobQ.front();
+        if (!lowJobQ.empty()) {
             auto diffTime = duration_cast<milliseconds>(
-                now - tempJob->requestTime).count();
-            if (diffTime >= this->attr.maxIdleTime) {
+                now - lowJobQ.front()->requestTime).count();
+            if (diffTime >= attr.maxIdleTime) {
                 /* If job has waited longer than the starvation time
                  * bump priority (add to higher priority Q) */
                 StatsAccountLQ(diffTime);
-                this->lowJobQ.pop_front();
-                this->medJobQ.push_back(tempJob);
+                medJobQ.push_back(std::move(lowJobQ.front()));
+                lowJobQ.pop_front();
                 continue;
             }
         }
@@ -367,25 +363,21 @@ static void SetSeed()
  * med priority, then low priority.
  *
  * If worker remains idle for more than specified max, the worker is released.
- *
- *! arg -> is cast to (ThreadPool::Internal *).
  */
-static void *WorkerThread(void *arg)
-{
-    auto tp = static_cast<ThreadPool::Internal *>(arg);
+void ThreadPool::Internal::WorkerThread() {
     time_t start = 0;
-    ThreadPoolJob *job = nullptr;
+    std::unique_ptr<ThreadPoolJob> job;
     std::cv_status retCode;
     int persistent = -1;
 
-    std::unique_lock<std::mutex> lck(tp->mutex, std::defer_lock);
-    auto idlemillis = std::chrono::milliseconds(tp->attr.maxIdleTime);
+    std::unique_lock<std::mutex> lck(mutex, std::defer_lock);
+    auto idlemillis = std::chrono::milliseconds(attr.maxIdleTime);
 
     /* Increment total thread count */
     lck.lock();
-    tp->totalThreads++;
-    tp->pendingWorkerThreadStart = 0;
-    tp->start_and_shutdown.notify_all();
+    totalThreads++;
+    pendingWorkerThreadStart = 0;
+    start_and_shutdown.notify_all();
     lck.unlock();
     
     SetSeed();
@@ -393,85 +385,83 @@ static void *WorkerThread(void *arg)
     while (true) {
         lck.lock();
         if (job) {
-            tp->busyThreads--;
-            delete job;
+            busyThreads--;
             job = nullptr;
         }
-        tp->stats.idleThreads++;
-        tp->stats.totalWorkTime += static_cast<double>(time(nullptr)) - static_cast<double>(start);
+        stats.idleThreads++;
+        stats.totalWorkTime += static_cast<double>(time(nullptr)) - static_cast<double>(start);
         start = time(nullptr);
         if (persistent == 0) {
-            tp->stats.workerThreads--;
+            stats.workerThreads--;
         } else if (persistent == 1) {
             /* Persistent thread becomes a regular thread */
-            tp->persistentThreads--;
+            persistentThreads--;
         }
 
         /* Check for a job or shutdown */
         retCode = std::cv_status::no_timeout;
-        while (tp->lowJobQ.empty() &&
-               tp->medJobQ.empty() &&
-               tp->highJobQ.empty() &&
-               !tp->persistentJob && !tp->shuttingdown) {
+        while (lowJobQ.empty() &&
+               medJobQ.empty() &&
+               highJobQ.empty() &&
+               !persistentJob && !shuttingdown) {
             /* If wait timed out and we currently have more than the
              * min threads, or if we have more than the max threads
              * (only possible if the attributes have been reset)
              * let this thread die. */
             if ((retCode == std::cv_status::timeout &&
-                 tp->totalThreads > tp->attr.minThreads) ||
-                (tp->attr.maxThreads != -1 &&
-                 tp->totalThreads > tp->attr.maxThreads)) {
-                tp->stats.idleThreads--;
+                 totalThreads > attr.minThreads) ||
+                (attr.maxThreads != -1 &&
+                 totalThreads > attr.maxThreads)) {
+                stats.idleThreads--;
                 goto exit_function;
             }
 
             /* wait for a job up to the specified max time */
-            retCode = tp->condition.wait_for(lck, idlemillis);
+            retCode = condition.wait_for(lck, idlemillis);
         }
 
-        tp->stats.idleThreads--;
+        stats.idleThreads--;
         /* idle time */
-        tp->stats.totalIdleTime += static_cast<double>(time(nullptr)) - static_cast<double>(start);
+        stats.totalIdleTime += static_cast<double>(time(nullptr)) - static_cast<double>(start);
         /* work time */
         start = time(nullptr);
         /* bump priority of starved jobs */
-        tp->bumpPriority();
+        bumpPriority();
         /* if shutdown then stop */
-        if (tp->shuttingdown) {
+        if (shuttingdown) {
             goto exit_function;
         } else {
             /* Pick up persistent job if available */
-            if (tp->persistentJob) {
-                job = tp->persistentJob;
-                tp->persistentJob = nullptr;
-                tp->persistentThreads++;
+            if (persistentJob) {
+                job = std::move(persistentJob);
+                persistentThreads++;
                 persistent = 1;
-                tp->start_and_shutdown.notify_all();
+                start_and_shutdown.notify_all();
             } else {
-                tp->stats.workerThreads++;
+                stats.workerThreads++;
                 persistent = 0;
                 /* Pick the highest priority job */
-                if (!tp->highJobQ.empty()) {
-                    job = tp->highJobQ.front();
-                    tp->highJobQ.pop_front();
-                    tp->CalcWaitTime(ThreadPool::HIGH_PRIORITY, job);
-                } else if (!tp->medJobQ.empty()) {
-                    job = tp->medJobQ.front();
-                    tp->medJobQ.pop_front();
-                    tp->CalcWaitTime(ThreadPool::MED_PRIORITY, job);
-                } else if (!tp->lowJobQ.empty()) {
-                    job = tp->lowJobQ.front();
-                    tp->lowJobQ.pop_front();
-                    tp->CalcWaitTime(ThreadPool::LOW_PRIORITY, job);
+                if (!highJobQ.empty()) {
+                    job = std::move(highJobQ.front());
+                    highJobQ.pop_front();
+                    CalcWaitTime(ThreadPool::HIGH_PRIORITY, job);
+                } else if (!medJobQ.empty()) {
+                    job = std::move(medJobQ.front());
+                    medJobQ.pop_front();
+                    CalcWaitTime(ThreadPool::MED_PRIORITY, job);
+                } else if (!lowJobQ.empty()) {
+                    job = std::move(lowJobQ.front());
+                    lowJobQ.pop_front();
+                    CalcWaitTime(ThreadPool::LOW_PRIORITY, job);
                 } else {
                     /* Should never get here */
-                    tp->stats.workerThreads--;
+                    stats.workerThreads--;
                     goto exit_function;
                 }
             }
         }
 
-        tp->busyThreads++;
+        busyThreads++;
         lck.unlock();
 
         SetPriority(job->priority);
@@ -483,9 +473,9 @@ static void *WorkerThread(void *arg)
 
 exit_function:
     LOGDEB("ThreadWorker: thread exiting\n");
-    tp->totalThreads--;
-    tp->start_and_shutdown.notify_all();
-    return nullptr;
+    totalThreads--;
+    start_and_shutdown.notify_all();
+    return;
 }
 
 /*!
@@ -515,7 +505,7 @@ int ThreadPool::Internal::createWorker(std::unique_lock<std::mutex>& lck)
         return EMAXTHREADS;
     }
     LOGDEB("ThreadPool::createWorker: creating thread\n");
-    std::thread nthread(WorkerThread, this);
+    auto nthread = std::thread([this] { WorkerThread(); });
     nthread.detach();
 
     /* wait until the new worker thread starts. We can set the flag
@@ -598,9 +588,6 @@ int ThreadPool::addPersistent(start_routine func, void *arg,
                               free_routine free_func,
                               ThreadPriority priority)
 {
-    int ret = 0;
-    ThreadPoolJob *job = nullptr;
-
     std::unique_lock<std::mutex> lck(m->mutex);
 
     /* Create A worker if less than max threads running */
@@ -609,20 +596,14 @@ int ThreadPool::addPersistent(start_routine func, void *arg,
     } else {
         /* if there is more than one worker thread
          * available then schedule job, otherwise fail */
-        if (m->totalThreads - m->persistentThreads - 1 == 0) {
-            ret = EMAXTHREADS;
-            goto exit_function;
-        }
-    }
-    
-    job = new ThreadPoolJob(func, arg, free_func, priority);
-    if (!job) {
-        ret = EOUTOFMEM;
-        goto exit_function;
+        if (m->totalThreads - m->persistentThreads - 1 == 0)
+            return EMAXTHREADS;
     }
+
+    auto job = std::make_unique<ThreadPoolJob>(std::move(func), arg, std::move(free_func), priority);
     job->jobId = m->lastJobId;
     job->requestTime = steady_clock::now();
-    m->persistentJob = job;
+    m->persistentJob = std::move(job);
 
     /* Notify a waiting thread */
     m->condition.notify_one();
@@ -632,37 +613,32 @@ int ThreadPool::addPersistent(start_routine func, void *arg,
         m->start_and_shutdown.wait(lck);
     m->lastJobId++;
 
-exit_function:
-    return ret;
+    return 0;
 }
 
 int ThreadPool::addJob(
     start_routine func, void *arg, free_routine free_func, ThreadPriority prio)
 {
-    ThreadPoolJob *job{nullptr};
-
     std::unique_lock<std::mutex> lck(m->mutex);
 
     int totalJobs = m->highJobQ.size() + m->lowJobQ.size() + m->medJobQ.size();
     if (totalJobs >= m->attr.maxJobsTotal) {
         LOGERR("ThreadPool::addJob: too many jobs: " << totalJobs << "\n");
-        goto exit_function;
+        return 0;
     }
 
-    job = new ThreadPoolJob(func, arg, free_func, prio);
-    if (!job)
-        goto exit_function;
+    auto job = std::make_unique<ThreadPoolJob>(std::move(func), arg, std::move(free_func), prio);
     job->jobId =  m->lastJobId;
     job->requestTime = steady_clock::now();
     switch (job->priority) {
     case HIGH_PRIORITY:
-        m->highJobQ.push_back(job);
+        m->highJobQ.push_back(std::move(job));
         break;
     case MED_PRIORITY:
-        m->medJobQ.push_back(job);
+        m->medJobQ.push_back(std::move(job));
         break;
     default:
-        m->lowJobQ.push_back(job);
+        m->lowJobQ.push_back(std::move(job));
     }
     /* AddWorker if appropriate */
     m->addWorker(lck);
@@ -670,7 +646,6 @@ int ThreadPool::addJob(
     m->condition.notify_one();
     m->lastJobId++;
 
-exit_function:
     return 0;
 }
 
@@ -730,32 +705,14 @@ int ThreadPool::shutdown()
 
 int ThreadPool::Internal::shutdown()
 {
-    ThreadPoolJob *temp = nullptr;
-
     std::unique_lock<std::mutex> lck(mutex);
 
-    while (!this->highJobQ.empty()) {
-        temp = this->highJobQ.front();
-        this->highJobQ.pop_front();
-        delete temp;
-    }
+    this->highJobQ.clear();
+    this->medJobQ.clear();
+    this->lowJobQ.clear();
 
-    while (!this->medJobQ.empty()) {
-        temp = this->medJobQ.front();
-        this->medJobQ.pop_front();
-        delete temp;
-    }
-
-    while (!this->lowJobQ.empty()) {
-        temp = this->lowJobQ.front();
-        this->lowJobQ.pop_front();
-        delete temp;
-    }
-    
     /* clean up long term job */
     if (this->persistentJob) {
-        temp = this->persistentJob;
-        delete temp;
         this->persistentJob = nullptr;
     }
     /* signal shutdown */
